summaryrefslogtreecommitdiff
path: root/src/inc
diff options
context:
space:
mode:
authorCarol Eidt <carol.eidt@microsoft.com>2018-12-03 12:52:20 -0800
committerGitHub <noreply@github.com>2018-12-03 12:52:20 -0800
commita089f64a7ad55a8ce0b3203b1bf87040775dff01 (patch)
treee408396ef22b34a5d06afbc235ee01ef29531e3e /src/inc
parent5632c9e3ac7f9dd6b858f175b2cf97963be996c4 (diff)
parent3bc3c61522c3a6c5663d5b4f9f535c4b3bc22a78 (diff)
downloadcoreclr-a089f64a7ad55a8ce0b3203b1bf87040775dff01.tar.gz
coreclr-a089f64a7ad55a8ce0b3203b1bf87040775dff01.tar.bz2
coreclr-a089f64a7ad55a8ce0b3203b1bf87040775dff01.zip
Merge pull request #21264 from fiigii/x64only
Implement 64-bit-only hardware intrinsic
Diffstat (limited to 'src/inc')
-rw-r--r--src/inc/corinfo.h20
1 files changed, 11 insertions, 9 deletions
diff --git a/src/inc/corinfo.h b/src/inc/corinfo.h
index 68eec6b57e..9b7a2f971a 100644
--- a/src/inc/corinfo.h
+++ b/src/inc/corinfo.h
@@ -213,11 +213,11 @@ TODO: Talk about initializing strutures before use
#define SELECTANY extern __declspec(selectany)
#endif
-SELECTANY const GUID JITEEVersionIdentifier = { /* 09F7AAE2-07DF-4433-B8C5-BA864CCABDA3 */
- 0x9f7aae2,
- 0x7df,
- 0x4433,
- {0xb8, 0xc5, 0xba, 0x86, 0x4c, 0xca, 0xbd, 0xa3}
+SELECTANY const GUID JITEEVersionIdentifier = { /* FF09DB9F-26A8-4A0B-AF2C-78E32A516FE1 */
+ 0xff09db9f,
+ 0x26a8,
+ 0x4a0b,
+ {0xaf, 0x2c, 0x78, 0xe3, 0x2a, 0x51, 0x6f, 0xe1}
};
//////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -2894,12 +2894,14 @@ public:
) = 0;
// Return method name as in metadata, or nullptr if there is none,
// and optionally return the class and namespace names as in metadata.
// Suitable for non-debugging use.
virtual const char* getMethodNameFromMetadata(
- CORINFO_METHOD_HANDLE ftn, /* IN */
- const char **className, /* OUT */
- const char **namespaceName /* OUT */
+ CORINFO_METHOD_HANDLE ftn, /* IN */
+ const char **className, /* OUT */
+ const char **namespaceName, /* OUT */
+ const char **enclosingClassName /* OUT */
) = 0;
// this function is for debugging only. It returns a value that
@@ -2894,12 +2894,14 @@ public:
) = 0;
// Return method name as in metadata, or nullptr if there is none,
- // and optionally return the class and namespace names as in metadata.
+ // and optionally return the class, enclosing class, and namespace names
+ // as in metadata.
// Suitable for non-debugging use.
virtual const char* getMethodNameFromMetadata(